# fewsats


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install fewsats_python in Development mode

``` sh
# make sure fewsats_python package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to fewsats_python
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/Fewsats/fewsats-python):

``` sh
$ pip install git+https://github.com/Fewsats/fewsats-python.git
```

or from [conda](https://anaconda.org/Fewsats/fewsats-python)

``` sh
$ conda install -c Fewsats fewsats
```

or from [pypi](https://pypi.org/project/fewsats-python/)

``` sh
$ pip install fewsats
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/Fewsats/fewsats-python)’s
[pages](https://Fewsats.github.io/fewsats-python/). Additionally you can
find package manager specific guidelines on
[conda](https://anaconda.org/Fewsats/fewsats-python) and
[pypi](https://pypi.org/project/fewsats-python/) respectively.

## How to use

The library allows you to check which payment methods you have available
and to pay for an offer.

``` python
from fewsats.core import *
```

``` python
fs = Client()
fs.get_payment_methods()
```

    [{'id': 2,
      'last4': '0355',
      'brand': 'mastercard',
      'exp_month': 12,
      'exp_year': 2026,
      'is_default': False},
     {'id': 4,
      'last4': '7346',
      'brand': 'visa',
      'exp_month': 12,
      'exp_year': 2028,
      'is_default': True}]
